@@ -95,6 +95,12 @@ func TestBuild(t *testing.T) {
 			args:        []string{"-p", "envTemplateCmd"},
 			expectImage: imageName + "1.0.0",
 		},
+		{
+			description: "envTemplate default tagger",
+			dir:         "testdata/tagPolicy",
+			args:        []string{"-p", "envTemplateDefault"},
+			expectImage: imageName + "bar",
+		},
 	}
 	for _, test := range tests {
 		t.Run(test.description, func(t *testing.T) {
