@@ -19,9 +19,8 @@ package docker
 import (
 	"fmt"
 	"path/filepath"
-	"strings"
 
-	"github.com/docker/docker/pkg/fileutils"
+	"github.com/moby/patternmatcher"
 
 	"github.com/GoogleContainerTools/skaffold/v2/pkg/skaffold/walk"
 )
@@ -29,7 +28,7 @@ import (
 // NewDockerIgnorePredicate creates a walk.Predicate that checks if directory entries
 // should be ignored.
 func NewDockerIgnorePredicate(workspace string, excludes []string) (walk.Predicate, error) {
-	matcher, err := fileutils.NewPatternMatcher(excludes)
+	matcher, err := patternmatcher.New(excludes)
 	if err != nil {
 		return nil, fmt.Errorf("invalid exclude patterns: %w", err)
 	}
@@ -39,38 +38,10 @@ func NewDockerIgnorePredicate(workspace string, excludes []string) (walk.Predica
 		if err != nil {
 			return false, err
 		}
-
-		ignored, err := matcher.Matches(relPath)
+		ignored, err := matcher.MatchesOrParentMatches(relPath)
 		if err != nil {
 			return false, err
 		}
-
-		if ignored && info.IsDir() && skipDir(relPath, matcher) {
-			return false, filepath.SkipDir
-		}
-
 		return ignored, nil
 	}, nil
 }
-
-// exclusion handling closely follows vendor/github.com/docker/docker/pkg/archive/archive.go
-func skipDir(relPath string, matcher *fileutils.PatternMatcher) bool {
-	// No exceptions (!...) in patterns so just skip dir
-	if !matcher.Exclusions() {
-		return true
-	}
-
-	dirSlash := relPath + string(filepath.Separator)
-
-	for _, pat := range matcher.Patterns() {
-		if !pat.Exclusion() {
-			continue
-		}
-		if strings.HasPrefix(pat.String()+string(filepath.Separator), dirSlash) {
-			// found a match - so can't skip this dir
-			return false
-		}
-	}
-
-	return true
-}
