@@ -23,8 +23,8 @@ import (
 	"path"
 	"path/filepath"
 
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
-	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/walk"
+	"github.com/GoogleContainerTools/skaffold/v2/pkg/skaffold/util"
+	"github.com/GoogleContainerTools/skaffold/v2/pkg/skaffold/walk"
 )
 
 // SyncMap creates a map of syncable files by looking at the COPY/ADD commands in the Dockerfile.
@@ -77,11 +77,13 @@ func walkWorkspaceWithDestinations(workspace string, excludes []string, fts []Fr
 		switch mode := fi.Mode(); {
 		case mode.IsDir():
 			keepFile := func(path string, info walk.Dirent) (bool, error) {
-				// Ignore non empty dirs
-				if info.IsDir() && !util.IsEmptyDir(path) {
-					return false, nil
+				if info.IsDir() && path == absFrom {
+					return true, nil
 				}
 
+				if util.IsEmptyDir(path) {
+					return true, nil
+				}
 				ignored, err := dockerIgnored(path, info)
 				if err != nil {
 					return false, err
