@@ -36,6 +36,7 @@ type kubernetesLogFormatter struct {
 	colorPicker     output.ColorPicker
 	prefix          string
 	JSONParseConfig latest.JSONParseConfig
+	kubeContext     string
 
 	pod       *v1.Pod
 	container v1.ContainerStatus
@@ -44,11 +45,12 @@ type kubernetesLogFormatter struct {
 	isMuted func() bool
 }
 
-func newKubernetesLogFormatter(config Config, colorPicker output.ColorPicker, isMuted func() bool, pod *v1.Pod, container v1.ContainerStatus) *kubernetesLogFormatter {
+func newKubernetesLogFormatter(config Config, colorPicker output.ColorPicker, isMuted func() bool, kubeContext string, pod *v1.Pod, container v1.ContainerStatus) *kubernetesLogFormatter {
 	return &kubernetesLogFormatter{
 		colorPicker:     colorPicker,
-		prefix:          prefix(config, pod, container),
+		prefix:          clusterPrefix(config, kubeContext, pod, container),
 		JSONParseConfig: config.JSONParseConfig(),
+		kubeContext:     kubeContext,
 		pod:             pod,
 		container:       container,
 		isMuted:         isMuted,
@@ -91,6 +93,13 @@ func (k *kubernetesLogFormatter) color() output.Color {
 	return output.None
 }
 
+func clusterPrefix(config Config, kubeContext string, pod *v1.Pod, container v1.ContainerStatus) string {
+	if config.IsMultiCluster() {
+		return fmt.Sprintf("[%s]%s", kubeContext, prefix(config, pod, container))
+	}
+	return prefix(config, pod, container)
+}
+
 func prefix(config Config, pod *v1.Pod, container v1.ContainerStatus) string {
 	var c latest.Pipeline
 	var present bool
