@@ -29,8 +29,10 @@ import (
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
+	"github.com/google/go-cmp/cmp/cmpopts"
 	"k8s.io/apimachinery/pkg/watch"
 	fake_testing "k8s.io/client-go/testing"
+	"sigs.k8s.io/kustomize/kyaml/yaml"
 )
 
 type T struct {
@@ -484,3 +486,15 @@ func SetupFakeWatcher(w watch.Interface) func(a fake_testing.Action) (handled bo
 		return true, w, nil
 	}
 }
+
+// YamlObj used in cmp.Diff, cmp.Equal to convert input from yaml string to map[string]any before comparison
+func YamlObj(t *testing.T) cmp.Option {
+	t.Helper()
+	return cmpopts.AcyclicTransformer("cmpYaml", func(in string) map[string]any {
+		var out map[string]any
+		if err := yaml.Unmarshal([]byte(in), &out); err != nil {
+			t.Fatalf("failed to unmarshal yaml to map: %v", err)
+		}
+		return out
+	})
+}
